@@ -46,3 +46,20 @@ class ValidatedJsonModelSerializerMixin(serializers.ModelSerializer):
             kwargs['json_validator_cls'] = model_field.json_validator_cls
 
         return field_class, kwargs
+
+
+
+try:
+    from drf_spectacular.extensions import OpenApiSerializerFieldExtension
+    from drf_spectacular.plumbing import build_basic_type
+    from drf_spectacular.types import OpenApiTypes
+
+    class ValidatedJsonFieldExtension(OpenApiSerializerFieldExtension):
+        target_class = ValidatedJSONField
+
+        def map_serializer_field(self, auto_schema, direction):
+            #print("schema", self.target.schema)
+            return self.target.schema
+except: pass
+
+    
